@@ -22,23 +22,34 @@
 #include "typedef.h"
 #include "packetParser.h"
 
-/** Return available crypto functions. For now we have
+#ifdef __cplusplus
+extern "C"{
+#endif
+
+/** Return available crypto functions.
+ * If more than 7 are available, returns the 7 first
  *
- * - Hash: HMAC-SHA256(Mandatory)
- * - CipherBlock: AES128(Mandatory)
+ * - Hash: HMAC-SHA256(Mandatory), HMAC-SHA384
+ * - CipherBlock: AES128(Mandatory), AES256
  * - Auth Tag: HMAC-SHA132 and HMAC-SHA180 (These are mandatory for SRTP and depends on the SRTP implementation thus we can just suppose they are both available)
- * - Key Agreement: DHM3k(Mandatory), DHM2k(optional and shall not be used except on low power devices)
+ * - Key Agreement: DHM3k(Mandatory), DHM2k(optional and shall not be used except on low power devices), X25519, X448
  * - Sas: base32(Mandatory), b256(pgp words)
  */
 uint8_t bzrtpUtils_getAvailableCryptoTypes(uint8_t algoType, uint8_t availableTypes[7]);
 
+/** Return available crypto functions.
+ * WARNING: this function can return more than 7 items, do not use it for something else than checking the
+ * values forced by bzrtp_setSupportedCryptoTypes
+ */
+uint8_t bzrtpUtils_getAllAvailableCryptoTypes(uint8_t algoType, uint8_t availableTypes[256]);
+
 /**
  *
  * @brief ZRTP Key Derivation Function as in rfc 4.5.1
- * 
+ *
  * KDF(KI, Label, Context, L) = HMAC(KI, i || Label ||
  *								0x00 || Context || L)
- * where 
+ * where
  * - i is a 32-bits integer fixed to 0x00000001
  * - L is a 32-bit big-endian positive
  *  integer, not to exceed the length in bits of the output of the HMAC.
@@ -59,7 +70,7 @@ uint8_t bzrtpUtils_getAvailableCryptoTypes(uint8_t algoType, uint8_t availableTy
 BZRTP_EXPORT int bzrtp_keyDerivationFunction(const uint8_t *key, const size_t keyLength,
 		const uint8_t *label, const size_t labelLength,
 		const uint8_t *context, const size_t contextLength,
-		const uint16_t hmacLength,
+		const uint8_t hmacLength,
 		void (*hmacFunction)(const uint8_t *, size_t, const uint8_t *, size_t, uint8_t, uint8_t *),
 		uint8_t *output);
 
@@ -90,7 +101,7 @@ void bzrtp_base256(uint32_t sas, char *output, int outputSize);
  * @brief CRC32 as defined in RFC4960 Appendix B - Polynomial is 0x1EDC6F41
  *
  * CRC is computed in reverse bit mode (least significant bit first within each byte)
- * reversed value of polynom (0x82F63B78) was used to compute the lookup table (source 
+ * reversed value of polynom (0x82F63B78) was used to compute the lookup table (source
  * http://en.wikipedia.org/wiki/Cyclic_redundancy_check#Commonly_used_and_standardized_CRCs)
  *
  * @param[in]	input	input data
@@ -99,7 +110,7 @@ void bzrtp_base256(uint32_t sas, char *output, int outputSize);
  * @return		the 32 bits CRC value
  *
  */
-BZRTP_EXPORT uint32_t bzrtp_CRC32(uint8_t *input, uint16_t length); 
+BZRTP_EXPORT uint32_t bzrtp_CRC32(uint8_t *input, uint16_t length);
 
 /* error code for the cryptoAlgoAgreement and function pointer update functions */
 #define	ZRTP_CRYPTOAGREEMENT_INVALIDCONTEXT		0x1001
@@ -110,6 +121,14 @@ BZRTP_EXPORT uint32_t bzrtp_CRC32(uint8_t *input, uint16_t length);
 #define ZRTP_CRYPTOAGREEMENT_INVALIDHASH		0x1006
 #define ZRTP_CRYPTOAGREEMENT_INVALIDAUTHTAG		0x1007
 #define ZRTP_CRYPTOAGREEMENT_INVALIDSAS			0x1008
+
+/**
+ * @brief Check if the keyAgreementAlgo is a post quantum algorithm
+ * @param[in]	keyAgreementAlgo	The key agreement algorithm
+ * @return	TRUE if the keyAgreementAlgo is a post quantum algorithm
+ */
+bool_t bzrtp_isPostQuantum(uint8_t keyAgreementAlgo);
+
 /**
  * @brief select a key agreement algorithm from the one available in context and the one provided by
  * peer in Hello Message as described in rfc section 4.1.2
@@ -148,7 +167,7 @@ BZRTP_EXPORT int bzrtp_updateCryptoFunctionPointers(bzrtpChannelContext_t *zrtpC
  *
  * @return		the number of common algorithms found
  */
-uint8_t selectCommonAlgo(uint8_t masterArray[7], uint8_t masterArrayLength, uint8_t slaveArray[7], uint8_t slaveArrayLength, uint8_t commonArray[7]);
+uint8_t bzrtp_selectCommonAlgo(uint8_t masterArray[7], uint8_t masterArrayLength, uint8_t *slaveArray, uint8_t slaveArrayLength, uint8_t commonArray[7]);
 
 /**
  * @brief add mandatory crypto functions if they are not already included
@@ -191,43 +210,131 @@ BZRTP_EXPORT void bzrtp_cryptoAlgoTypeIntToString(uint8_t algoTypeInt, uint8_t a
  * @param[in]		keyLength	The keyLength in bytes
  * @param[in]		rngContext	The context for RNG
  */
-BZRTP_EXPORT void bzrtp_DestroyKey(uint8_t *key, uint8_t keyLength, void *rngContext);
+BZRTP_EXPORT void bzrtp_DestroyKey(uint8_t *key, size_t keyLength, void *rngContext);
 
 /**
- * @brief Convert an hexadecimal string into the corresponding byte buffer
+ * @brief Destroy all the key material of a channel context
  *
- * @param[out]	outputBytes			The output bytes buffer, must have a length of half the input string buffer
- * @param[in]	inputString			The input string buffer, must be hexadecimal(it is not checked by function, any non hexa char is converted to 0)
- * @param[in]	inputStringLength	The length in chars of the string buffer, output is half this length
+ * @param[in,out] zrtpContext           The zrtp context
+ * @param[in,out] zrtpChannelContext    The channel context
  */
-void bzrtp_strToUint8(uint8_t *outputBytes, uint8_t *inputString, uint16_t inputStringLength);
+void bzrtp_destroyKeyMaterial(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpChannelContext);
 
 /**
- * @brief Convert a byte buffer into the corresponding hexadecimal string
+ * Return the public value(public key or ciphertext) length in bytes according to given key agreement algorithm and packet type
+ * packet type is used to determine public value type when in KEM mode:
+ *     - commit holds a public key
+ *     - DHPart1 holds a ciphertext
+ *     - DHPart2 holds a nonce
+ *
+ * @param[in]    keyAgreementAlgo    The key agreement algo mapped to an integer as defined in cryptoUtils.h
+ * @param[in]    messageType            MSGTYPE_COMMIT, MSGTYPE_DHPART1i or MSGTYPE_DHPART2: needed for KEM mode
+ *
+ * @return        the public value length in bytes
  *
- * @param[out]	outputString		The output string buffer, must have a length of twice the input bytes buffer
- * @param[in]	inputBytes			The input bytes buffer
- * @param[in]	inputBytesLength	The length in bytes buffer, output is twice this length
  */
-void bzrtp_int8ToStr(uint8_t *outputString, uint8_t *inputBytes, uint16_t inputBytesLength);
+BZRTP_EXPORT uint16_t bzrtp_computeKeyAgreementPublicValueLength(uint8_t keyAgreementAlgo, uint8_t messageTyoe);
 
 /**
- * @brief	convert an hexa char [0-9a-fA-F] into the corresponding unsigned integer value
- * Any invalid char will be converted to zero without any warning
+ * Return the shared secret size in bytes according to given key agreement algorithm
  *
- * @param[in]	inputChar	a char which shall be in range [0-9a-fA-F]
+ * @param[in]	keyAgreementAlgo	The key agreement algo mapped to an integer as defined in cryptoUtils.h
+ *
+ * @return		the shared secrert length in bytes
  *
- * @return		the unsigned integer value in range [0-15]
  */
-uint8_t bzrtp_charToByte(uint8_t inputChar);
+uint16_t bzrtp_computeKeyAgreementSharedSecretLength(uint8_t keyAgreementAlgo, uint8_t hashLength);
 
 /**
- * @brief	convert a byte which value is in range [0-15] into an hexa char [0-9a-fA-F]
+ * Check a given key agrement algorithm is a KEM or not
+ * @param[in]	keyAgreementAlgo a key agreement algo mapped on a uint8_t
  *
- * @param[in]	inputByte	an integer which shall be in range [0-15]
- *
- * @return		the hexa char [0-9a-f] corresponding to the input
+ * @return TRUE if the algorithm is of type KEM, FALSE otherwise
  */
-uint8_t bzrtp_byteToChar(uint8_t inputByte);
+bool_t bzrtp_isKem(uint8_t keyAgreementAlgo);
+
+/**
+ * Compute the variable size of data in a Commit message based on the given key agreement algorithm
+ * For DH types, it is the hvi size, for KEM types, it is the hvi size + public key size, for preShared or multistream the nonce size
+ *
+ * @param[in]	keyAgreementAlgo a key agreement algo mapped on a uint8_t
+ *
+ * @return the size in bytes of the variable part in a Commit message, 0 in case of unknown keyAgreementAlgo
+ */
+uint16_t bzrtp_computeCommitMessageVariableLength(uint8_t keyAgreementAlgo);
+
+/* have a C interface to the KEM defined in c++ in bctoolbox
+ TODO: build bzrtp in c++ and directly use the bctoolbox interface */
+/* Forward declaration of KEM context */
+typedef struct bzrtp_KEMContext_struct bzrtp_KEMContext_t;
+
+/**
+ * Create the KEM context
+ *
+ * @param[in]	keyAgreementAlgo one of ZRTP_KEYAGREEMENT_KYB1, ZRTP_KEYAGREEMENT_KYB2, ZRTP_KEYAGREEMENT_KYB3,
+ * 									ZRTP_KEYAGREEMENT_HQC1, ZRTP_KEYAGREEMENT_HQC2, ZRTP_KEYAGREEMENT_HQC3,
+ *									ZRTP_KEYAGREEMENT_K255_KYB512, ZRTP_KEYAGREEMENT_K255_HQC128,
+ *									ZRTP_KEYAGREEMENT_K448_KYB1024, ZRTP_KEYAGREEMENT_K448_HQC256
+ *									ZRTP_KEYAGREEMENT_K255_KYB512_HQC128, ZRTP_KEYAGREEMENT_K448_KYB1024_HQC256,
+ *
+ * @return a pointer to the created context, NULL in case of failure
+ */
+bzrtp_KEMContext_t *bzrtp_createKEMContext(uint8_t keyAgreementAlgo, uint8_t hashAlgo);
+
+/**
+ * Generate a key pair and store it in the context
+ *
+ * @return 0 on success
+ */
+int bzrtp_KEM_generateKeyPair(bzrtp_KEMContext_t *ctx);
+
+/**
+ * Extract the public key from context
+ * @param[in]	ctx			a valid KEM context
+ * @param[out]	publicKey	the key in this context. Data is copied in this buffer, caller must ensure it is the correct size
+ *
+ * @return 0 on success
+ */
+int bzrtp_KEM_getPublicKey(bzrtp_KEMContext_t *ctx, uint8_t *publicKey);
+
+/**
+ * Extract the shared secret from context
+ * @param[in]	ctx				a valid KEM context
+ * @param[out]	sharedSecret	the shared secret in this context. Data is copied in this buffer, caller must ensure it is the correct size
+ *
+ * @return 0 on success
+ */
+int bzrtp_KEM_getSharedSecret(bzrtp_KEMContext_t *ctx, uint8_t *sharedSecret);
+
+/**
+ * Generate and encapsulate a secret given a public key, shared secret is stored in the context
+ * @param[in]	ctx				a valid KEM context
+ * @param[in]	publicKey		the public key we want to encapsulate to
+ * @param[out]	cipherText		the encapsulated secret
+ *
+ * @return 0 on success
+ */
+int bzrtp_KEM_encaps(bzrtp_KEMContext_t *ctx, uint8_t *publicKey, uint8_t *cipherText);
+
+/**
+ * Decapsulate a key, shared secret is stored in the context
+ *
+ * @param[in]	ctx				a valid KEM context holding the secret Key needed to decapsulate
+ * @param[in]	cipherText		the encapsulated secret
+ *
+ * @return 0 on success
+ */
+int bzrtp_KEM_decaps(bzrtp_KEMContext_t *ctx, uint8_t *cipherText);
+
+/**
+ * Destroy a KEM context. Safely clean any secrets it may holding
+ * @param[in]	ctx				a valid KEM context
+ *
+ * @return 0 on success
+ */
+int bzrtp_destroyKEMContext(bzrtp_KEMContext_t *ctx);
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* CRYPTOUTILS_H */
