@@ -17,6 +17,8 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <bctoolbox/defs.h>
+
 #include <stdio.h>
 #include "bzrtpTest.h"
 #include "typedef.h"
@@ -59,14 +61,14 @@ end:
 	return res;
 }
 
-int silent_arg_func(const char *arg) {
+int silent_arg_func(BCTBX_UNUSED(const char *arg)) {
 	bctbx_set_log_level(log_domain, BCTBX_LOG_FATAL);
 	bctbx_set_log_level(BCTBX_LOG_DOMAIN, BCTBX_LOG_FATAL);
 	verbose = 0;
 	return 0;
 }
 
-int verbose_arg_func(const char *arg) {
+int verbose_arg_func(BCTBX_UNUSED(const char *arg)) {
 	bctbx_set_log_level(log_domain, BCTBX_LOG_DEBUG);
 	bctbx_set_log_level(BCTBX_LOG_DOMAIN,BCTBX_LOG_DEBUG);
 	verbose = 1;
@@ -84,7 +86,7 @@ void bzrtp_tester_init(void(*ftester_printf)(int level, const char *fmt, va_list
 	bc_tester_set_verbose_func(verbose_arg_func);
 	bc_tester_set_logfile_func(logfile_arg_func);
 	if (ftester_printf == NULL) ftester_printf = log_handler;
-	bc_tester_init(ftester_printf, BCTBX_LOG_MESSAGE, BCTBX_LOG_ERROR, NULL);
+	bc_tester_init(ftester_printf, BCTBX_LOG_MESSAGE, BCTBX_LOG_ERROR, "patternZIDAlice.sqlite");
 
 	bc_tester_add_suite(&crypto_utils_test_suite);
 	bc_tester_add_suite(&packet_parser_test_suite);
