@@ -20,17 +20,25 @@
 #ifndef bzrtpTester_h
 #define bzrtpTester_h
 
-#define BCTOOLBOX_LOG_DOMAIN "bzrtp-tester"
 #include <bctoolbox/logging.h>
 
 #define bzrtp_message bctbx_message
 
 #include <bctoolbox/tester.h>
 
+#ifdef __cplusplus
+extern "C"{
+#endif
+
 extern test_suite_t crypto_utils_test_suite;
 extern test_suite_t packet_parser_test_suite;
 extern test_suite_t zidcache_test_suite;
 extern test_suite_t key_exchange_test_suite;
 
 extern int verbose;
+
+#ifdef __cplusplus
+};
+#endif
+
 #endif // bzrtpTester_h
